#
# spec file for package python-simplejson
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-simplejson
Version:        3.19.3
Release:        1.2
Summary:        Extensible JSON encoder/decoder for Python
License:        AFL-2.1 OR MIT
Group:          Development/Languages/Python
URL:            https://github.com/simplejson/simplejson
Source:         https://files.pythonhosted.org/packages/source/s/simplejson/simplejson-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
simplejson is an extensible JSON encoder and decoder for Python 2.5+. It is
pure Python code with no dependencies, but includes an optional C extension for
a speed boost.

%prep
%setup -q -n simplejson-%{version}

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build

%install
%python_install
%python_expand rm -rf %{buildroot}%{$python_sitearch}/simplejson/tests/
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.txt README.rst
%{python_sitearch}/simplejson*

%changelog
* Sun Sep  8 2024 Dirk Müller <dmueller@suse.com>
- update to 3.19.3:
  * Updated test & build matrix to include Python 3.13.
  * Dropped wheel support for Python 2.7 on macOS.
  * https://github.com/simplejson/simplejson/pull/326
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 3.19.2:
  * Updated test & build matrix to include Python 3.12
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 3.19.1:
  * This release contains security hardening measures based on
    recommendations by a security audit sponsored by OSTIF and
    conducted by X41 D-Sec GmbH.
    Several of these measures include changing defaults to be
    more strict, by default simplejson will now only consume
    and produce compliant JSON, but the flags still exist for
    any backwards compatibility needs.
    No high priority issues were discovered, the reference
    count leak is thought to be unreachable since the digits of the
    float are checked before PyOS_string_to_double is called.
  * Fix invalid handling of unicode escape sequences in the pure
    Python implementation of the decoder (SJ-PT-23-01)
  * Fix missing reference count decrease if PyOS_string_to_double
    raises an exception in Python 2.x; was probably unreachable (SJ-
    PT-23-02)
  * Backport the integer string length limitation from Python
    3.11 to limit quadratic number parsing (SJ-PT-23-03)
  * Fix inconsistencies with error messages between the C and
    Python implementations (SJ-PT-23-100)
  * Remove unused unichr import from encoder (SJ-PT-23-101)
  * Remove unused namedtuple_as_object and tuple_as_array
    arguments from simplejson.load (SJ-PT-23-102)
  * Remove vestigial _one_shot code from iterencode (SJ-
    PT-23-103)
  * Change default of allow_nan from True to False and add
    allow_nan to decoder (SJ-PT-23-107)
  * Test the sdist to prevent future regressions
  * Fix regression in sdist archive
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 3.18.1:
  * Remove unnecessary `i` variable from encoder module namespace
  * Declare support for Python 3.11 and add wheels
* Sun Dec  4 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v3.18.0
  * Allow serialization of classes that implement for_json or _asdict by
  ignoring TypeError when those methods are called
  https://github.com/simplejson/simplejson/pull/302
  * Raise JSONDecodeError instead of ValueError in invalid unicode escape
  sequence edge case
  https://github.com/simplejson/simplejson/pull/298
* Mon Nov 29 2021 Dirk Müller <dmueller@suse.com>
- update to 3.17.6:
  * Declare support for Python 3.10 and add wheels
* Tue Sep  7 2021 Dirk Müller <dmueller@suse.com>
- update to 3.17.5:
  * Fix the C extension module to harden is_namedtuple against looks-a-likes such
    as Mocks. Also prevent dict encoding from causing an unraised SystemError when
    encountering a non-Dict. Noticed by running user tests against a CPython
    interpreter with C asserts enabled (COPTS += -UNDEBUG).
* Fri Jul 16 2021 Dirk Müller <dmueller@suse.com>
- update to 3.17.3:
  * Replaced Travis-CI and AppVeyor with Github Actions,
    adding wheels for Python 3.9.
* Wed Jul 29 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 3.17.2
- use pytest as testrunner
* Sun Nov 24 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 3.17.0:
  * Updated documentation to be Python 3 first, and
    have removed documentation notes about version changes
    that occurred more than five years ago.
    https://github.com/simplejson/simplejson/pull/257
    https://github.com/simplejson/simplejson/pull/254
  * Update build matrix for Python 3.8
    https://github.com/simplejson/simplejson/pull/255
    https://github.com/simplejson/simplejson/pull/256
* Sat Sep  8 2018 Arun Persaud <arun@gmx.de>
- update to version 3.16.1:
  * Added examples for JSON lines use cases
  * Add wheels for more Python versions and platforms
* Mon Jul  2 2018 tchvatal@suse.com
- Do not package tests
* Mon Jul  2 2018 arun@gmx.de
- specfile:
  * be more specific in %%files:
    %%{python_sitearch}/* -> %%{python_sitearch}/simplejson*
- update to version 3.16.0:
  * Restore old behavior with regard to the type of decoded empty
    strings with speedups enabled on Python 2.x
    https://github.com/simplejson/simplejson/pull/225
  * Add python_requires to setup.py to help pip
    https://github.com/simplejson/simplejson/pull/224
  * Fix CSS in docs when built locally
    https://github.com/simplejson/simplejson/pull/222
* Mon May 21 2018 arun@gmx.de
- update to version 3.15.0:
  * Clean up the C code
  * Bypass the decode() method in bytes subclasses
  * Support builds without cStringIO
  * Allow to disable serializing bytes by default in Python 3
  * Simplify the compatibility code
  * Fix tests in Python 2.5
* Sun May  6 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 3.14.0:
  * Defer is_raw_json test (performance improvement)
    https://github.com/simplejson/simplejson/pull/212
  * Avoid escaping U+2028 and U+2029 without ensure_ascii
    https://github.com/simplejson/simplejson/pull/211
  * Fix an incorrect type test in Python 2, avoiding an unnecessary
    unicode copy.  https://github.com/simplejson/simplejson/pull/210
* Mon Nov 27 2017 jengelh@inai.de
- Remove bias from description.
* Sun Nov 26 2017 arun@gmx.de
- update to version 3.13.2:
  * Fix additional Python 2.x compilation issue on Windows
- changes from version 3.13.1 :
  * Improve CI to catch speedups build regressions
  * Fix speedups build regression in Python 2.x
    https://github.com/simplejson/simplejson/issues/193
- changes from version 3.13.0:
  * Workarounds for NamedTemporaryFile issues with Windows for tool
    tests
  * Make TypeError messages contain type name instead of a repr.
    https://github.com/simplejson/simplejson/pull/191
  * Ensure that encoding of text subtypes is consistent with or
    without speedups
    https://github.com/simplejson/simplejson/issues/185
- changes from version 3.12.1:
  * Misc updates to build infrastructure
  * Fix an assertion failure when make_encoder receives a bad encoder
    argument https://github.com/simplejson/simplejson/pull/188
  * Fix potential crash during GC
    https://github.com/simplejson/simplejson/pull/187
  * Fix a reference leak when sorting keys
    https://github.com/simplejson/simplejson/pull/186
* Mon Nov  6 2017 arun@gmx.de
- update to version 3.12.0:
  * Fix threaded import race condition
    https://github.com/simplejson/simplejson/issues/184
  * Move RawJSON implementation to simplejson.raw_json module
  * Move JSONDecodeError implementation to simplejson.errors module
* Tue Aug  8 2017 tbechtold@suse.com
- update to 3.11.1:
  * Fix issue with item_sort_key when speedups are available, and add
    auto-discovery to test suites to prevent similar regressions
  * docstring fix in JSONEncoder
  * Call PyObject_IsTrue() only once for the strict argument of scann  er
  * Fix a crash with unencodable encoding in the encoder
  * Remove unused imports
  * Remove remnants of Python 2.4 support
  * Fix argument checking errors in _speedups.c
  * Remove the `__init__` methods in extension classes
  * Fix typo in the doc for loads
  * Add Python 3.6 to testing matrix and PyPI metadata
* Tue Mar 21 2017 jmatejek@suse.com
- fix pypi url
* Thu Mar 16 2017 rjschwei@suse.com
- Switch to single-spec build
- Update to 3.10.0
  * Add RawJSON class to allow a faster path for already encoded JSON.
- From 3.9.0
  * Workaround for bad behavior in string subclasses
  * Fix warnings flagged by -3
  * Update readthedocs documentation links
  * Add build status badge to README
* Fri Nov 18 2016 dmueller@suse.com
- update to 3.8.2:
  * Fix implicit cast compiler warning in _speedups.c
  * simplejson is now available as wheels for OS X and Windows thanks to Travis-CI
  and AppVeyor respectively! Many thanks to @aebrahim for getting this party
  started.
  * Fix issue with iterable_as_array and indent option
  * Fix typo in keyword argument name introduced in 3.8.0
  * New iterable_as_array encoder option to perform lazy serialization of
  any iterable objects, without having to convert to tuple or list.
  * Fix typo introduced in 3.7.0 (behavior should be indistinguishable)
  https://github.com/simplejson/simplejson/commit/e18cc09b688ea1f3305c27616fd3cadd2adc6d31#commitcomment-11443842
  * Do not cache Decimal class in encoder, only reference the decimal module.
  This may make reload work in more common scenarios.
  * Fix compilation with MSVC
  https://github.com/simplejson/simplejson/pull/119
  * simplejson no longer trusts custom str/repr methods for int, long, float
  subclasses. These instances are now formatted as if they were exact
  instances of those types.
  https://github.com/simplejson/simplejson/issues/118
* Tue May 12 2015 benoit.monin@gmx.fr
- update to version 3.6.5:
  * Importing bug fix for reference leak when an error occurs
    during dict encoding
    https://github.com/simplejson/simplejson/issues/109
- additional changes from version 3.6.4:
  * Important bug fix for dump when only sort_keys is set
    https://github.com/simplejson/simplejson/issues/106
- additional changes from version 3.6.3:
  * Documentation updates
    https://github.com/simplejson/simplejson/issues/103
- additional changes from version 3.6.2:
  * Documentation updates
    http://bugs.python.org/issue21514
- additional changes from version 3.6.1:
  * Documentation updates
    https://github.com/simplejson/simplejson/issues/102
- additional changes from version 3.6.0:
  * Automatically strip any UTF-8 BOM from input to more closely
    follow the latest specs
    https://github.com/simplejson/simplejson/pull/101
- additional changes from version 3.5.3:
  * Fix lower bound checking in scan_once / raw_decode API
    https://github.com/simplejson/simplejson/issues/98
* Sat May 31 2014 dmueller@suse.com
- update to 3.5.2:
  * Fix Windows build with VS2008
  Version 3.5.1 released 2014-05-21
  * Consistently reject int_as_string_bitcount settings that are not
    positive integers
  Version 3.5.0 released 2014-05-20
  * Added int_as_string_bitcount encoder option
  * Fixed potential crash when encoder created with incorrect options
* Tue May 20 2014 toddrme2178@gmail.com
- Update to 3.4.1
  * Fixed tests to run on Python 3.4
- Update to 3.4.0
  * Native setuptools support re-introduced
    https://github.com/simplejson/simplejson/pull/92
- Update to 3.3.3
  * Improve test suite's Python 3.4 compatibility
    https://github.com/simplejson/simplejson/issues/87
- Update to 3.3.2
  * Docstring fix for decoded string types
    https://github.com/simplejson/simplejson/pull/82
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Oct 21 2013 dmueller@suse.com
- update to 3.3.1:
  * JSONDecodeError exceptions can now be pickled
* Wed May  8 2013 benny.gaechter@gmail.com
- Update to version 3.3.0
  * Unpaired surrogates once again pass through the decoder, to match older
    behavior and the RFC-4627 spec.
    https://github.com/simplejson/simplejson/issues/62
* Thu Feb 21 2013 p.drouand@gmail.com
- Update to version 3.1.3
  * Updated documentation to discourage subclassing whenever possible.
    default, object_hook, and object_pairs_hook provide almost all of
    the functionality of subclassing.
- Update to version 3.1.2
  * Updated documentation to reflect separators behavior when indent is
    not None
  * Test suite should be compatible with debug builds of Python 2.x and 3.x
- Update to version 3.1.1
  * setup.py now has another workaround for Windows machines without
    MSVC installed
- Update to version 3.1.0
  * Updated JSON conformance test suite
  * simplejson.tool tests and bugfix for Python 3.x
  * Improve error messages for certain kinds of truncated input
  * Moved JSONDecodeError to json.scanner (still available for import
    from json.decoder)
  * Changed scanner to use JSONDecodeError directly rather than
    StopIteration to improve error messages
- Update to version 3.0.9
  * Fix an off-by-one error in the colno property of JSONDecodeError
    (when lineno == 1)
* Thu Feb 21 2013 p.drouand@gmail.com
- Update to version 3.0.8:
  * Fix a Python 2.x compiler warning for narrow unicode builds
    https://github.com/simplejson/simplejson/issues/56
* Thu Jan 17 2013 toddrme2178@gmail.com
- Update to 3.0.7
  * NOTE: this release only changes the license.
  * simplejson is now dual-licensed software, MIT or AFL v2.1. It is
    also made explicit that this code is also licensed to the PSF under
    a Contributor Agreement.
- Update to 3.0.7
  * Fix for major Python 2.x ensure_ascii=False encoding regression
    introduced in simplejson 3.0.0. If you use this setting, please
    upgrade immediately.
* Fri Jan 11 2013 p.drouand@gmail.com
- Initial python3 support
* Fri Jan 11 2013 p.drouand@gmail.com
- Update to 3.0.5:
  * NOTE: this release only changes the tests, it is
    not essential to upgrade
  * Tests now run with deprecation warnings printed
  * Fixed Python 3 syntax error in simplejson.tool
    https://github.com/simplejson/simplejson/issues/49
  * Fixed Python 3.3 deprecation warnings in test suite
    https://github.com/simplejson/simplejson/issues/48
- Update to 3.0.4 version:
  * MSVC compatibility for Python 3.3
    https://github.com/simplejson/simplejson/pull/47
- Update to 3.0.3 version:
  * Fixes for bugs introduced in 3.0.2
  * Fixes for Python 2.5 compatibility
  * MSVC compatibility for Python 2.x
    https://github.com/simplejson/simplejson/pull/46
- Update to 3.0.0 version:
  * Python 3.3 is now supported, thanks to Vinay Sajip
    https://github.com/simplejson/simplejson/issues/8
  * `sort_keys`/`item_sort_key` now sort on the stringified verison of the
    key, rather than the original object. This ensures that the sort
    only compares string types and makes the behavior consistent between
    Python 2.x and Python 3.x.
  * Like other number types, Decimal instances used as keys are now
    coerced to strings when use_decimal is True.
* Sat Sep 29 2012 os-dev@jacraig.com
- Update to 2.6.2:
  * JSONEncoderForHTML was not exported in the simplejson module
* Mon Sep  3 2012 os-dev@jacraig.com
- Update to 2.6.1:
  * raw_decode() now skips whitespace before the object
- Changes from 2.6.0:
  * Error messages changed to match proposal for Python 3.3.1
* Fri May 25 2012 toddrme2178@gmail.com
- Clean up spec file
- Update to version 2.5.2:
  * Fix for regression introduced in 2.5.1
- Update to version 2.5.1:
  * Support for use_decimal=True in environments that use Python
    sub-interpreters such as uWSGI
- Update to version 2.5.1:
  * New item_sort_key option for encoder to allow fine grained
    control of sorted output
* Mon Mar 12 2012 saschpe@gmx.de
- Update to version 2.4.0:
  * New bigint_as_string option for encoder to trade JavaScript number
    precision issues for type issues.
- Run testsuite
- Package README.rst, CHANGES.txt and LICENSE.txt
* Tue Sep 20 2011 saschpe@suse.de
- Re-add python-distribute, you can't simply remove that, it breaks RPM updates
* Tue Sep  6 2011 alexandre@exatati.com.br
- Update to 2.2.1:
  * Fix MANIFEST.in issue when building a sdist from a sdist.
    https://github.com/simplejson/simplejson/issues/16
- Aditional changes from version 2.2.0:
  * Remove setuptools requirement, reverted to pure distutils
  * use_decimal default for encoding (dump, dumps, JSONEncoder) is now True
  * tuple encoding as JSON objects can be turned off with new
    tuple_as_array=False option.
    https://github.com/simplejson/simplejson/pull/6
  * namedtuple (or other tuple subclasses with _asdict methods) are now
    encoded as JSON objects rather than arrays by default. Can be disabled
    and treated as a tuple with the new namedtuple_as_object=False option.
    https://github.com/simplejson/simplejson/pull/6
  * JSONDecodeError is now raised instead of ValueError when a document
    ends with an opening quote and the C speedups are in use.
    https://github.com/simplejson/simplejson/issues/15
  * Updated documentation with information about JSONDecodeError
  * Force unicode linebreak characters to be escaped (U+2028 and U+2029)
    http://timelessrepo.com/json-isnt-a-javascript-subset
  * Moved documentation from a git submodule to
    http://simplejson.readthedocs.org/
* Mon May  9 2011 alexandre@exatati.com.br
- Update to 2.1.6:
  * Prevent segfaults with deeply nested JSON documents
    https://github.com/simplejson/simplejson/issues/11
  * Fix compatibility with Python 2.5
    https://github.com/simplejson/simplejson/issues/5
  - Aditional changes from 2.1.5 released 2011-04-17:
  * Built sdist tarball with setuptools_git installed. Argh.
  - Aditional changes from 2.1.4 released 2011-04-17:
  * Does not try to build the extension when using PyPy
  * Trailing whitespace after commas no longer emitted when indent is used
  * Migrated to github http://github.com/simplejson/simplejson
- Regenerate spec file with py2pack.
* Thu Mar  3 2011 saschpe@suse.de
- Update to 2.1.3
  * Support the sort_keys option in C encoding speedups
  * Allow use_decimal to work with dump()
  * Correct wrong end when object_pairs_hook is used
  * Correct output for indent=0
  * Correctly raise TypeError when non-string keys are used with
    speedups
  * Fix the endlineno, endcolno attributes of the JSONDecodeError
    exception.
* Mon Jul  5 2010 alexandre@exatati.com.br
- Update to 2.1.1:
  * Corrected simplejson.__version__ and other minor doc changes.
  * Do not fail speedups tests if speedups could not be built.
  * Decimal serialization officially supported for encoding with
  use_decimal=True. For encoding this encodes Decimal objects and
  for decoding it implies parse_float=Decimal
  * Decoding performance and memory utilization enhancements
  ... see CHANGES.txt for more
- Spec file cleaned with spec-cleaner.
* Mon May 25 2009 James Oakley <jfunk@funktronics.ca>
- Update to 2.0.9
- Split off doc package
* Wed Dec  3 2008 James Oakley <jfunk@funktronics.ca>
- Update to 2.0.5
* Wed Mar 19 2008 James Oakley <jfunk@funktronics.ca>
- Update to 1.7.5
* Tue Oct 30 2007 James Oakley <jfunk@funktronics.ca>
- Update to 1.7.3
  Sun Sep 09 00:00:00 UTC 2007 - Peter Nixon
- first build
